<?php
namespace Service\IssueLog;

use Doctrine\ORM\EntityManager;
use Zeedhi\DevOps\Model\Projectmanagement\Entities;
use Zeedhi\DevOps\Model\Projectmanagement\EntitiesInterface\Log\TaskLogInterface;
use Util\Utilities;

class IssueLog
{
    const TYPE_UPDATE = 'UPDATE';
    const TYPE_INSERT = 'INSERT';
    const TYPE_DELETE = 'DELETE';
    const ISSUE_TABLE = 'TASK';

    /** @var EntityManager $entityManager */
    private $entityManager;

    /** @var Utilities $environment */
    private $environment;

    /** @var Entities\TaskLog $taskLogRepository */
    private $taskLogRepository;

    /** @var \Factory\TaskLog $taskLogFactory */
    private $taskLogFactory;

    /***********************************************************************
     * Constructor.
     ***********************************************************************/
    public function __construct(EntityManager $entityManager, Utilities $utilities,
                                \Factory\TaskLog $taskLogFactory)
    {
        $this->entityManager = $entityManager;
        $this->environment = $utilities;
        $this->taskLogRepository = $this->entityManager->getRepository(Utilities::ENTITY_DIR.'TaskLog');
        $this->taskLogFactory = $taskLogFactory;
    }

    /***********************************************************************
     * Creates log itself.
     ***********************************************************************/
    protected function createLog($logType, $tableName, $columnName, $oldValue = null, $newValue = null, $task)
    {
        $taskLogEntity = $this->taskLogFactory->createIssueLog();

        $taskLogEntity->setLogType($logType);
        $taskLogEntity->setTableName($tableName);
        $taskLogEntity->setColumnName($columnName);
        $taskLogEntity->setOldValue($oldValue);
        $taskLogEntity->setTask($task);
        $taskLogEntity->setNewValue($newValue);

        $this->entityManager->persist($taskLogEntity);
    }

    /***********************************************************************
     * Gets modified issue id.
     ***********************************************************************/
    protected function getTask($entity){
        if($entity instanceof Entities\Allocation){
            return $this->entityManager->getRepository(Utilities::ENTITY_DIR.'Task')->find($entity->getTask()->getId());
        }
        return $entity;
    }

    /***********************************************************************
     * Log of update type.
     ***********************************************************************/
    public function logUpdate(TaskLogInterface $entity, $oldValue, $newValue, $tableName, $column)
    {
        $this->createLog(self::TYPE_UPDATE, $tableName, $column, $oldValue, $newValue, $this->getTask($entity));
    }

    /***********************************************************************
     * Log of insert type.
     ***********************************************************************/
    public function logInsert(TaskLogInterface $entity, $oldValue, $newValue, $tableName, $column)
    {
        $this->createLog(self::TYPE_INSERT, $tableName, $column, $oldValue, $newValue, $this->getTask($entity));
    }

} 