/*
NOME: 0008_CARSTPO_USR_EXPORTAREQUISICAO.SQL
DESCRIO: Procedimento para exportao da posio de estoque e ajustes de estoque.
CRIAO: 30/01/2012 - Marcelo Alexsandro Souza Silva
*/

CREATE OR REPLACE
PROCEDURE USR_EXPORTAREQUISICAO
  (P_DTINICIAL    IN DATE,
   P_DTFINAL      IN DATE) IS

   V_DTGRV         DATE;
   V_HRGRV         VARCHAR2(4);
   V_CDSERVFILI    VARCHAR2(5);
   V_CDPRODUTOFIN  VARCHAR2(10);
   V_CDFILIAL      VARCHAR(4);

   V_PRXCONSPLAN   VARCHAR2(20);
   V_PRXCODIGO     VARCHAR2(20);
   V_QTCOMESTICAR  FLOAT;
   V_NOVOCODIGO    INTEGER;

   V_OLDIDUTRETIPRAT SERVICO.IDUTRETIPRAT%TYPE;

   V_RETURN        VARCHAR2(1);
   V_ERROR         VARCHAR2(4000);

   /* - Declarao de cursores ---------------------------------------------- */

   CURSOR C_FILIAIS IS
      SELECT CDFILIAL
        FROM FILGRUPFILI
       WHERE FILGRUPFILI.CDGRUPFILI = '9999999999';
BEGIN
   V_RETURN := USR_FUNC_BLOQUEIO('USR_INT_PREVRETI', 'B');
   IF V_RETURN = 'S' THEN
      V_DTGRV := NULL;
      V_HRGRV := NULL;

      /* Retorna data e hora de exportao */
      BEGIN
        SELECT TO_DATE(SYSDATE), TO_CHAR(SYSDATE,'HH24MI')
          INTO V_DTGRV, V_HRGRV
          FROM DUAL;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN
           V_DTGRV := NULL;
           V_HRGRV := NULL;
      END;

      OPEN C_FILIAIS;
      LOOP
        FETCH C_FILIAIS INTO V_CDFILIAL;
        EXIT WHEN C_FILIAIS%NOTFOUND;

        NOVO_CODIGO('CONSPLAN'||V_CDFILIAL, V_PRXCONSPLAN);
        V_PRXCONSPLAN := SUBSTR(V_PRXCONSPLAN,11,10);

        NOVO_CODIGO('USR_INT_PREVRETI', V_PRXCODIGO);
        V_NOVOCODIGO := TO_NUMBER(V_PRXCODIGO);

        FOR C_SERVICO IN
           (SELECT CDSERVFILI
              FROM SERVICO
             WHERE CDFILIAL = V_CDFILIAL)
        LOOP
           BEGIN
              SELECT NVL(IDUTRETIPRAT, 'N')
              INTO V_OLDIDUTRETIPRAT
              FROM SERVICO
              WHERE CDFILIAL = V_CDFILIAL
                AND CDSERVFILI = C_SERVICO.CDSERVFILI;
           EXCEPTION
              WHEN NO_DATA_FOUND THEN V_OLDIDUTRETIPRAT := 'N';
           END;

           UPDATE SERVICO
              SET IDUTRETIPRAT = 'S'
            WHERE CDFILIAL = V_CDFILIAL
              AND CDSERVFILI = C_SERVICO.CDSERVFILI;

           CONSUMO_PLANEJADO_PLA(V_CDFILIAL,
                                 C_SERVICO.CDSERVFILI,
                                 TRUNC(P_DTINICIAL),
                                 TRUNC(P_DTFINAL),
                                 'P',
                                 'CXX',
                                 'P',
                                 0,
                                 'S',
                                 V_PRXCONSPLAN,
                                 '0',
                                 'ZZZZZZZZZZZZZZZZZZZZ',
                                 '000000092420');

           UPDATE SERVICO
              SET IDUTRETIPRAT = V_OLDIDUTRETIPRAT
            WHERE CDFILIAL = V_CDFILIAL
              AND CDSERVFILI = C_SERVICO.CDSERVFILI;
           COMMIT;

           FOR C_PREVRETI IN
              (SELECT
                  PR.ROWID,
                  PR.CDFILIAL,
                  PR.CDSERVFILI,
                  PR.DTPREVRETI,
                  PR.NRREQUEXTR,
                  PR.IDPREVRETI,
                   P.CDARVPROD CDPRODUTO,
                  PR.DTLIMITERETI,
                  PR.HRLIMITERETI,
                  PR.NRPRPREVRETI,
                  PR.QTPREVRETI,
                  PR.CDTIPOPRAT,
                  PR.CDFILAUXPRAT,
                  PR.CDPRATO
                 FROM PREVRETI PR, PRODUTO P
                WHERE PR.CDFILIAL   = V_CDFILIAL
                  AND PR.DTPREVRETI BETWEEN P_DTINICIAL AND P_DTFINAL
                  AND PR.CDSERVFILI = C_SERVICO.CDSERVFILI
                  AND PR.NRREQUEXTR = '0000000000'
                  AND PR.IDPREVRETI = 'C'
                  AND PR.CDPRODUTO  = P.CDPRODUTO
             ORDER BY PR.CDFILIAL, PR.CDSERVFILI, PR.DTPREVRETI, PR.CDPRODUTO)
           LOOP
              DELETE FROM PREVRETI
               WHERE ROWID = C_PREVRETI.ROWID;

              DELETE FROM USR_INT_PREVRETI
               WHERE CDFILIAL = C_PREVRETI.CDFILIAL
                 AND CDSERVFILI = C_PREVRETI.CDSERVFILI
                 AND DTPREVRETI = C_PREVRETI.DTPREVRETI
                 AND CDPRODUTO = C_PREVRETI.CDPRODUTO
                 AND IDORIGREGISTRO = 'T';

              SELECT SUM(QTCOMESTICAR) AS QTCOMESTICAR
                INTO V_QTCOMESTICAR
              FROM CARDADIA
              WHERE (CDFILIAL   = C_PREVRETI.CDFILIAL)
                AND (CDSERVFILI = C_PREVRETI.CDSERVFILI)
                AND (DTCARDAPIO = C_PREVRETI.DTPREVRETI);

              INSERT INTO USR_INT_PREVRETI
                 (NRSEQUENCIAL, CDFILIAL, CDSERVFILI, DTPREVRETI, NRREQUEXTR, IDPREVRETI, CDPRODUTO,
                  DTLIMITERETI, HRLIMITERETI, NRPRPREVRETI, QTPREVRETI, QTCOMESTICAR,
                  CDTIPOPRAT, CDFILAUXPRAT, CDPRATO, IDORIGREGISTRO, DTGRAVACAO,
                  HRGRAVACAO, DTIMPORTACAO, HRIMPORTACAO)
              VALUES
                 (V_NOVOCODIGO, C_PREVRETI.CDFILIAL, C_PREVRETI.CDSERVFILI, C_PREVRETI.DTPREVRETI,
                  C_PREVRETI.NRREQUEXTR, C_PREVRETI.IDPREVRETI, C_PREVRETI.CDPRODUTO, C_PREVRETI.DTLIMITERETI, C_PREVRETI.HRLIMITERETI,
                  C_PREVRETI.NRPRPREVRETI, C_PREVRETI.QTPREVRETI, V_QTCOMESTICAR,
                  C_PREVRETI.CDTIPOPRAT, C_PREVRETI.CDFILAUXPRAT, C_PREVRETI.CDPRATO, 'T', NULL,
                  NULL, NULL, NULL);
           END LOOP;
           COMMIT;
        END LOOP;
        UPDATE USR_INT_PREVRETI
           SET DTGRAVACAO = V_DTGRV, HRGRAVACAO = V_HRGRV
         WHERE NRSEQUENCIAL = V_NOVOCODIGO;
        V_CDFILIAL := '';
        COMMIT;
      END LOOP;
      CLOSE C_FILIAIS;
      V_RETURN := USR_FUNC_BLOQUEIO('USR_INT_PREVRETI', 'D');
   END IF;
EXCEPTION
  WHEN OTHERS THEN BEGIN
     IF V_RETURN = 'S' THEN
        V_ERROR:= SQLERRM(SQLCODE);
        V_RETURN := USR_FUNC_BLOQUEIO('USR_INT_PREVRETI', 'D', V_ERROR);
     END IF;
  END;
END;
/

-- VERSAO --
BEGIN ATUVEROBJ('USR_EXPORTAREQUISICAO','5.09.xxx'); END;
/
